@@ -88,19 +88,14 @@ class GitIssuePublisher(Publisher):
         """
         try:
             title = f"Automated Issue on branch {self.branch}"
-            print(1)
             existing_issue = self.get_thread(title)
-
-            print(2)
             updated_body = self.generate_issue(existing_issue.body or '', 
                                                         message=data['message']['adherence']['score'],
                                                         vulnerability=data['codeVulnerability']['score'])
-            print(3)
             existing_issue.edit(body=updated_body)
-            print(4)
             existing_issue.create_comment(self.generate_report(data))
 
-            return 
+            return
         except GithubException as e:
             raise Exception(f"Error publishing issue: {e}")
  
@@ -151,15 +146,14 @@ class GitIssuePublisher(Publisher):
             "\n**Code Vulnerability:**\n",
             f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}",
             f"  *{data['codeVulnerability']['comment']}*\n",
-            "\n**SOLID Principles Analysis:**\n",
-            "| Principle            | Score | Comment |\n",
-            "|----------------------|-------|---------|\n"
+            "\n**SOLID Principles Analysis:**\n"
         ]
 
         for principle, details in data['codeSOLID'].items():
-            report.append(
-                f"| {principle.replace('_', ' ').title()} | {details['score']} {details['emoji']} | *{details['comment']}* |"
-            )
+            report.append(f"- **{principle.replace('_', ' ').title()}**")
+            report.append(f"  - **Score:** {details['score']} {details['emoji']}")
+            report.append(f"  *{details['comment']}*\n")
+
 
         return '\n'.join(report)
 
@@ -196,18 +190,7 @@ class WebPublisher(Publisher):
     def sort_data(self, data: Dict[str, Any], others: Dict[str, Any] = None) -> Dict[str, Any]:
         if others is None:
             others = {}
-        sorted_data = {
-            'message': data['message'].get('message', ''),
-            'suggested': data['message'].get('suggested', ''),
-            'adherence': data['message'].get('adherence', ''),
-            'completeness': data['message'].get('completeness', ''),
-            'atomicity': data['code']['acid_score'].get('a', ''),
-            'consistency': data['code']['acid_score'].get('c', ''),
-            'isolation': data['code']['acid_score'].get('i', ''),
-            'durability': data['code']['acid_score'].get('d', ''),
-            'vulnerability': data['code']['vulnerable_code'].get('score', ''),
-        }
-        sorted_data.update(others)
+        data.update(others)
         return sorted_data
 
 
